<?php
/**
 * Includes Form Hanlder
 */
if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists("EnWooAddonsFormHandler")) {

    class EnWooAddonsFormHandler extends EnWooAddonsInclude {

        public $settings;
        public $sections;
        public $section;
        public $plugin_id;
        public $plugins_dependencies;
        public $plugins_dependencies_script_css_files;
        protected $plugin_detail;

        /**
         * construct
         */
        public function __construct() {
            
            $this->plugins_dependencies = $this->plugins_dependencies();
            $this->plugins_dependencies_script_css_files = $this->plugins_dependencies_script_css_files();
            add_filter('en_woo_addons_settings', array($this, 'en_woo_addons_settings_arr'), 10, 3);
            add_action('woocommerce_settings_tabs_array', array($this, 'en_woo_addons_popup_notifi_disabl_to_plan'), 10);
        }

        /**
         * load_files_plugin_dependencies including css, style, script
         * @param array type $files_arr
         */
        public function load_files_plugin_dependencies($files_arr, $addon_type) {

            foreach ($files_arr as $key => $value) {

                switch ($key) {

                    case "templates":
                        array_filter($value, function ($template) use($addon_type) {

                            include_once( addon_plugin_url . '/admin/templates/' . $template . '.php');
                        });
                        break;

                    case "css":
                        array_filter($value, function ($css_file) use($addon_type) {

                            wp_register_style($addon_type . '_' . $css_file . '_style', plugin_dir_url(__FILE__) . '../admin/assets/css/' . $css_file . '.css', false, '1.2');
                            wp_enqueue_style($addon_type . '_' . $css_file . '_style');
                        });
                        break;

                    case "script":
                        array_filter($value, function ($script_file) use($addon_type) {

                            wp_enqueue_script($addon_type . '_' . $script_file . '_script', plugin_dir_url(__FILE__) . '../admin/assets/js/' . $script_file . '.js', array(), '1.0');
                            wp_localize_script($addon_type . '_' . $script_file . '_script', 'script', array('pluginsUrl' => plugins_url(),));
                        });

                        break;
                }
            }
        }

        /**
         * Update web api settings array 
         * @param array $settings
         * @param string $section
         * @param string $plugin_id
         * @return array
         */
        public function en_woo_addons_settings_arr($settings, $section, $plugin_id) {

            $this->settings = $settings;
            $this->section = $section;
            $this->plugin_id = $plugin_id;
            $this->settings = $this->get_settings();
            return $this->settings;
        }

        /**
         * Find out exact module is running and return his fields web settings array 
         * @return array
         */
        public function get_settings() {

            if (isset($this->plugins_dependencies[$this->plugin_id])) {

                $plugin_detail = $this->plugins_dependencies[$this->plugin_id];
                $addons = $plugin_detail['addons'];

                if ($addons['auto_residential_detection_addon']['active'] === true && $this->section == $addons['auto_residential_detection_addon']['section']) {

                    $this->load_files_plugin_dependencies($this->plugins_dependencies_script_css_files['auto_residential_detection_addon'], 'auto_residential_detection_addon');
                    $EnWooAddonAutoResidDetectionTemplate = new EnWooAddonAutoResidDetectionTemplate();
                    $this->settings = $EnWooAddonAutoResidDetectionTemplate->auto_residential_detection_addon($this->settings, $addons, $this->plugin_id);

                    if ($addons['lift_gate_delivery_addon']['active'] === true && $this->section == $addons['lift_gate_delivery_addon']['section']) {

                        $this->load_files_plugin_dependencies($this->plugins_dependencies_script_css_files['lift_gate_delivery_addon'], 'lift_gate_delivery_addon');
                        $this->settings = apply_filters('en_woo_addons_check_for_lift_gate_delivery_option', $this->settings, $addons, $this->plugin_id);
                    }
                }
            }

            return $this->settings;
        }

        /**
         * Array merge after specific index 
         * @param array $array
         * @param index of array $key
         * @param array $new
         * @return array
         */
        public function addon_array_insert_after(array $array, $key, array $new) {

            if (isset($key) && in_array($key, array_keys($array))) {

                $keys = array_keys($array);
                $index = array_search($key, $keys);
                $pos = false === $index ? count($array) : $index + 1;
                $array = array_merge(array_slice($array, 0, $pos), $new, array_slice($array, $pos));
            }

            return $array;
        }

        /**
         * Formate the given date time @param $datetime like in sow
         * @param datetime $datetime
         * @return string 
         */
        public function formate_date_time($datetime) {

            $date = date_create($datetime);
            return date_format($date, "M. d, Y");
        }

        /**
         * get_arr_filterd_val function see for if @param $arr_val type is array reset value return
         * @param array or string type $arr_val
         * @return string type
         */
        public function get_arr_filterd_val($arr_val) {

            return (isset($arr_val) && (!empty($arr_val)) ) ? (is_array($arr_val)) ? reset($arr_val) : $arr_val : "";
        }

        /**
         * Popup notification for using notification show during disable to plan through using jquery
         * @return html
         */
        public function en_woo_addons_popup_notifi_disabl_to_plan() {
            ?>
            <div id="plan_confirmation_popup" class="sm_notification_disable_to_plan_overlay">
                <div class="sm_wwe_small_notifi_disabl_to_plan">
                    <h2 class="del_hdng">
                        Note!
                    </h2>
                    <p class="confirmation_p">
                        Note! You have elected to enable the automatically detect residential addresses feature. By confirming this election you will be charged for the <span id="selected_plan_popup">[plan]</span> plan. To ensure service continuity the plan will automatically renew each month, or when the plan is depleted, whichever comes first. You can change which plan is put into effect on the next renewal date by updating the selection on this page at anytime.
                    </p>
                    <div class="confirmation_btns">
                        <a style="cursor: pointer" class="cancel_plan">Cancel</a>
                        <a style="cursor: pointer" class="confirm_plan">OK</a>
                    </div>
                </div>
            </div>
            <?php
        }

    }

}

new EnWooAddonsFormHandler();
